@@ -1,6 +1,6 @@
 /*
  *	libHX/opt.c
- *	Copyright © Jan Engelhardt, 2002-2011
+ *	Copyright Jan Engelhardt, 2002-2011
  *
  *	This file is part of libHX. libHX is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU Lesser
@@ -941,7 +941,9 @@ EXPORT_SYMBOL struct HXmap *HX_shconfig_map(const char *file)
 		return NULL;
 
 	if ((fp = fopen(file, "r")) == NULL) {
-		free(map);
+		int saved_errno = errno;
+		HXmap_free(map);
+		errno = saved_errno;
 		return NULL;
 	}
 
